@@ -10,5 +10,5 @@ def build_environment_dict(environment_obj: typing.Any) -> dict:
     return environment_schema.dump(environment_obj)
 
 
-def build_environment_model(environment_obj: object) -> EnvironmentModel:
-    return environment_schema.load(build_environment_dict(environment_obj))
+def build_environment_model(environment_dict: dict) -> EnvironmentModel:
+    return environment_schema.load(environment_dict)
